@@ -6,10 +6,10 @@
 # Unless required by applicable law or agreed to in writing, software
 # distributed under the License is distributed on an "AS IS" BASIS,
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-from headless.core import Resource
+from .picqerresource import PicqerResource
 
 
-class Warehouse(Resource):
+class Warehouse(PicqerResource):
     idwarehouse: int
     name: str
     accept_orders: bool
